netapp_ontap.resources.metrocluster_operation API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.metrocluster_operation`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

# Overview

Retrieves a list of recent MetroCluster operations. To view more information about a specific operation, use the `/cluster/metrocluster/operations/{uuid}` API endpoint.

####

## Examples

### Retrieves all MetroCluster operations

    GET https://<mgmt-ip>/api/cluster/metrocluster/operations?fields=*
    {
        "records": [
            {
                "uuid": "a14ae39f-8d85-11e9-b4a7-00505682dc8b",
                "type": "check",
                "state": "successful",
                "start_time": "2019-06-14T11:15:00-07:00",
                "end_time": "2019-06-14T11:16:08-07:00",
                "_links": {
                    "self": {
                        "href": "/api/cluster/metrocluster/operations/a14ae39f-8d85-11e9-b4a7-00505682dc8b"
                    }
                }
            },
            {
                "uuid": "7058df27-8d85-11e9-bbc9-005056826931",
                "type": "configure",
                "state": "successful",
                "start_time": "2019-06-12T19:46:27-07:00",
                "end_time": "2019-06-12T19:48:17-07:00",
                "_links": {
                    "self": {
                        "href": "/api/cluster/metrocluster/operations/7058df27-8d85-11e9-bbc9-005056826931"
                    }
                }
            },
            {
                "uuid": "7849515d-8d84-11e9-bbc9-005056826931",
                "type": "connect",
                "state": "successful",
                "start_time": "2019-06-12T19:39:30-07:00",
                "end_time": "2019-06-12T19:42:02-07:00",
                "_links": {
                    "self": {
                        "href": "/api/cluster/metrocluster/operations/7849515d-8d84-11e9-bbc9-005056826931"
                    }
                }
            },
            {
                "uuid": "331c79ad-8d84-11e9-b4a7-00505682dc8b",
                "type": "interface_create",
                "state": "successful",
                "start_time": "2019-06-12T19:37:35-07:00",
                "end_time": "2019-06-12T19:37:41-07:00",
                "_links": {
                    "self": {
                        "href": "/api/cluster/metrocluster/operations/331c79ad-8d84-11e9-b4a7-00505682dc8b"
                    }
                }
            }
        ],
        "num_records": 4,
        "_links": {
            "self": {
                "href": "/api/cluster/metrocluster/operations?fields=%2A"
            }
        }
    }

### Retrieves Information about a specific MetroCluster operation

    GET https://<mgmt-ip>/api/cluster/metrocluster/operations/0db12274-86fd-11e9-8053-00505682c342
    {
        "uuid": "0db12274-86fd-11e9-8053-00505682c342",
        "name": "check",
        "state": "successful",
        "start_time": "2019-06-06T16:15:01-07:00",
        "end_time": "2019-06-06T16:16:05-07:00",
        "_links": {
            "self": {
                "href": "/api/cluster/metrocluster/operations/0db12274-86fd-11e9-8053-00505682c342"
            }
        }
    }

## Classes

`class MetroclusterOperation (*args, **kwargs)`

  Data for a MetroCluster operation. REST: /api/cluster/metrocluster/operations

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all MetroclusterOperation resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent MetroclusterOperation resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the list of MetroCluster operations on the local cluster.

    ### Related ONTAP Commands

    - `metrocluster operation history show`

    ### Learn more

    - `DOC /cluster/metrocluster/operations`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves the list of MetroCluster operations on the local cluster.

    ### Related ONTAP Commands

    - `metrocluster operation history show`

    ### Learn more

    - `DOC /cluster/metrocluster/operations`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves information about a specific MetroCluster operation.

    ### Related ONTAP Commands

    - `metrocluster operation show`

    ### Learn more

    - `DOC /cluster/metrocluster/operations`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class MetroclusterOperationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MetroclusterOperation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `additional_info: str GET`

    Additional information for the auto heal.

    Example: MetroCluster switchover with auto heal completed successfully.

  `command_line: str GET`

    Command line executed with the options specified.

    Example: metrocluster switchover

  `end_time: ImpreciseDateTime GET`

    End Time

    Example: 2016-03-10T22:35:16.000+0000

  `errors: List[str] GET`

    List of errors in the operation.

    Example: ["siteB (warning): Unable to prepare the partner cluster for a pending switchback operation. Reason: entry doesn't exist. Reboot the nodes in the partner cluster before using the "metrocluster switchback" command."]

  `links: SelfLink GET`

    The links field of the metrocluster_operation.

  `node: Node GET POST PATCH`

    The node field of the metrocluster_operation.

  `start_time: ImpreciseDateTime GET`

    Start Time

    Example: 2016-03-10T22:33:16.000+0000

  `state: str GET`

    Indicates the state of the operation.

    Valid choices:

    - completed_with_manual_recovery_needed
    - completed_with_warnings
    - failed
    - in_progress
    - partially_successful
    - successful
    - unknown
  `type: str GET`

    Name of the operation.

    Valid choices:

    - check
    - configure
    - connect
    - disconnect
    - dr_group_create
    - dr_group_delete
    - heal_aggr_auto
    - heal_aggregates
    - heal_root_aggr_auto
    - heal_root_aggregates
    - interface_create
    - interface_delete
    - interface_modify
    - ip_setup
    - ip_teardown
    - modify
    - switchback
    - switchback_continuation_agent
    - switchback_simulate
    - switchover
    - switchover_simulate
    - unconfigure
    - unconfigure_continuation_agent
    - unknown
  `uuid: str GET`

    Identifier for the operation.

    Example: 11111111-2222-3333-4444-abcdefabcdef